/*
 *  Font Draw
 *
 *  A program to draw a font bitmap from another font,
 *  perhaps a native font. This allows the bitmap to
 *  be manipulated and used as a pixel source.
 *
 *  You'll need to get a screen shot of the window
 *  and save it into a bitmap file if you want to load
 *  it and manipulate it.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <app.h>

int app_native_font_width(Font *f);

App *app;
Window *w;
Font *f;
int max_width;
int line_height;

void draw_font_window(Window *w, Graphics *g)
{
	int x, y;
	int i;
	char ch[2];

	ch[1] = '\0';
	app_set_font(g, f);

	app_draw_rect(g, rect(0, 0,
				32 * max_width + 2,
				8 * line_height + 2));

	/* Draw the ISO Latin 1 set. */
	for (i = 0; i < 256; i++)
	{
		ch[0] = i;

		x = (i % 32) * max_width;
		y = (i / 32) * line_height;

		app_draw_utf8(g, pt(x+1, y+1), ch, 1);
	}
}

void make_native_font_window(char *font_name, int style, int pixel_size)
{
	f = app_new_font(app, font_name, style, pixel_size);
	max_width = app_native_font_width(f);
	line_height = app_font_height(f);

	w = app_new_window(app,
			rect(50, 50, max_width * 32 + 2, line_height * 8 + 2),
			font_name,
			STANDARD_WINDOW);
	app_on_window_redraw(w, draw_font_window);
	app_show_window(w);
	app_main_loop(app);
	app_del_window(w);
	app_del_font(f);
}

int main(int argc, char *argv[])
{
	char *font_name = "Times";
	int style = PLAIN;
	int height = 16;
	int i;

	for (i = 1; i < argc; i++)
	{
		if (strcmp(argv[i], "bold") == 0)
			style |= BOLD;
		else if (strcmp(argv[i], "italic") == 0)
			style |= ITALIC;
		else if (strcmp(argv[i], "plain") == 0)
			style = PLAIN;
		else if ((argv[i][0] >= '0') && (argv[i][0] <= '9'))
			height = atoi(argv[i]);
		else
			font_name = argv[i];
	}

	app = app_new_app(argc, argv);
	make_native_font_window(font_name, style, height);
	app_del_app(app);

	return 0;
}
